==> haskell-quickcheck-2.14.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 QuickCheck
version:              2.14.1
visibility:           public
id:                   QuickCheck-2.14.1-64ImYjtdVDWOmMrx53wi
key:                  QuickCheck-2.14.1-64ImYjtdVDWOmMrx53wi
license:              BSD-3-Clause
copyright:
    2000-2019 Koen Claessen, 2006-2008 Björn Bringert, 2009-2019 Nick Smallbone

maintainer:           Nick Smallbone <nick@smallbone.se>
author:               Koen Claessen <koen@chalmers.se>
homepage:             https://github.com/nick8325/quickcheck
synopsis:             Automatic testing of Haskell programs
description:
    QuickCheck is a library for random testing of program properties.
    The programmer provides a specification of the program, in the form of
    properties which functions should satisfy, and QuickCheck then tests that the
    properties hold in a large number of randomly generated cases.
    Specifications are expressed in Haskell, using combinators provided by
    QuickCheck. QuickCheck provides combinators to define properties, observe the
    distribution of test data, and define test data generators.

    Most of QuickCheck'\''s functionality is exported by the main "Test.QuickCheck"
    module. The main exception is the monadic property testing library in
    "Test.QuickCheck.Monadic".

    If you are new to QuickCheck, you can try looking at the following resources:

    * The <http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html official QuickCheck manual>.
    It'\''s a bit out-of-date in some details and doesn'\''t cover newer QuickCheck features,
    but is still full of good advice.
    * <https://begriffs.com/posts/2017-01-14-design-use-quickcheck.html>,
    a detailed tutorial written by a user of QuickCheck.

    The <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>
    companion package provides instances for types in Haskell Platform packages
    at the cost of additional dependencies.

category:             Testing
abi:                  9452ff431c267398842e1e389fdfc82e
exposed:              True
exposed-modules:
    Test.QuickCheck Test.QuickCheck.All Test.QuickCheck.Arbitrary
    Test.QuickCheck.Exception Test.QuickCheck.Features
    Test.QuickCheck.Function Test.QuickCheck.Gen
    Test.QuickCheck.Gen.Unsafe Test.QuickCheck.Modifiers
    Test.QuickCheck.Monadic Test.QuickCheck.Poly
    Test.QuickCheck.Property Test.QuickCheck.Random
    Test.QuickCheck.State Test.QuickCheck.Test Test.QuickCheck.Text

import-dirs:          /usr/lib/ghc-8.10.2/site-local/QuickCheck-2.14.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/QuickCheck-2.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/QuickCheck-2.14.1
hs-libraries:         HSQuickCheck-2.14.1-64ImYjtdVDWOmMrx53wi
depends:
    base-4.14.1.0 containers-0.6.2.1 deepseq-1.4.4.0
    random-1.2.0-9ZKOj3LHVp86TAE4mLSgtI
    splitmix-0.1.0.3-GzZJw92O7YKKbbUoRegvbC template-haskell-2.16.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-quickcheck/html/QuickCheck.haddock
haddock-html:         /usr/share/doc/haskell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-2.14.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 QuickCheck
version:              2.14.2
visibility:           public
id:                   QuickCheck-2.14.2-HuWX0x2YbXiDJIIRNzg91f
key:                  QuickCheck-2.14.2-HuWX0x2YbXiDJIIRNzg91f
license:              BSD-3-Clause
copyright:
    2000-2019 Koen Claessen, 2006-2008 Björn Bringert, 2009-2019 Nick Smallbone

maintainer:           Nick Smallbone <nick@smallbone.se>
author:               Koen Claessen <koen@chalmers.se>
homepage:             https://github.com/nick8325/quickcheck
synopsis:             Automatic testing of Haskell programs
description:
    QuickCheck is a library for random testing of program properties.
    The programmer provides a specification of the program, in the form of
    properties which functions should satisfy, and QuickCheck then tests that the
    properties hold in a large number of randomly generated cases.
    Specifications are expressed in Haskell, using combinators provided by
    QuickCheck. QuickCheck provides combinators to define properties, observe the
    distribution of test data, and define test data generators.

    Most of QuickCheck'\''s functionality is exported by the main "Test.QuickCheck"
    module. The main exception is the monadic property testing library in
    "Test.QuickCheck.Monadic".

    If you are new to QuickCheck, you can try looking at the following resources:

    * The <http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html official QuickCheck manual>.
    It'\''s a bit out-of-date in some details and doesn'\''t cover newer QuickCheck features,
    but is still full of good advice.
    * <https://begriffs.com/posts/2017-01-14-design-use-quickcheck.html>,
    a detailed tutorial written by a user of QuickCheck.

    The <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>
    companion package provides instances for types in Haskell Platform packages
    at the cost of additional dependencies.

category:             Testing
abi:                  a92418060127f287d15386ede2d3353d
exposed:              True
exposed-modules:
    Test.QuickCheck Test.QuickCheck.All Test.QuickCheck.Arbitrary
    Test.QuickCheck.Exception Test.QuickCheck.Features
    Test.QuickCheck.Function Test.QuickCheck.Gen
    Test.QuickCheck.Gen.Unsafe Test.QuickCheck.Modifiers
    Test.QuickCheck.Monadic Test.QuickCheck.Poly
    Test.QuickCheck.Property Test.QuickCheck.Random
    Test.QuickCheck.State Test.QuickCheck.Test Test.QuickCheck.Text

import-dirs:          /usr/lib/ghc-8.10.2/site-local/QuickCheck-2.14.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/QuickCheck-2.14.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/QuickCheck-2.14.2
hs-libraries:         HSQuickCheck-2.14.2-HuWX0x2YbXiDJIIRNzg91f
depends:
    base-4.14.1.0 containers-0.6.2.1 deepseq-1.4.4.0
    random-1.2.0-7whe9vPfCIO8FAl3LEVyJX
    splitmix-0.1.0.3-2XwNp7DUGqOLHYeYlbizyN template-haskell-2.16.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-quickcheck/html/QuickCheck.haddock
haddock-html:         /usr/share/doc/haskell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
